<p align="center">
  <a href="#"><img src="docs/images/logo.png" alt="audioperm"></a>
</p>
<p align="center">
    <em>Audioperm, a python library for generating different permutations of audible segments from audio files.</em>
</p>
<p align="center">
<a href="https://pypi.org/project/autoocr/" target="_blank">
    <img src="https://img.shields.io/pypi/v/autoocr?color=%2334D058&label=pypi%20package" alt="Package version">
</a>
</p>

---
### Audioperm
A python library for generating different permutations of audible segments from audio files. 

#### Use:

* Silence Removal from Audio
* Audio / Speech augmentation
* Add new synthetic data for deep learning
* Speaker recognition, Speaker verification, Audio classification, Audio fingerprinting


**Documentation**: <a href="https://github.com/zabir-nabil/audioperm/docs" target="_blank">https://github.com/zabir-nabil/audioperm/docs</a>

**Source Code**: <a href="https://github.com/zabir-nabil/audioperm" target="_blank">https://github.com/zabir-nabil/audioperm</a>

---